@@ -72,6 +72,8 @@ class Manager(clients.ServiceClients):
         self.qos_client = self.network.QosClient()
         self.qos_min_bw_client = self.network.QosMinimumBandwidthRulesClient()
         self.segments_client = self.network.SegmentsClient()
+        self.trunks_client = self.network.TrunksClient()
+        self.log_resource_client = self.network.LogResourceClient()
 
     def _set_image_clients(self):
         if CONF.service_available.glance:
@@ -263,6 +265,8 @@ class Manager(clients.ServiceClients):
             self.volume_v3.SchedulerStatsClient()
         self.volume_transfers_client_latest = \
             self.volume_v3.TransfersClient()
+        self.volume_transfers_mv355_client_latest = \
+            self.volume_v3.TransfersV355Client()
         self.volume_availability_zone_client_latest = \
             self.volume_v3.AvailabilityZoneClient()
         self.volume_limits_client_latest = self.volume_v3.LimitsClient()
